==> MafDb.ESP6500SI.V2.SSA137_3.2.0.tar.gz: MafDb.ESP6500SI.V2.SSA137/inst/MafDbPkgTemplate/man/MafDb.ESP6500SI.V2.SSA137-package.Rd <==
\name{MafDb.ESP6500SI.V2.SSA137-package}
\alias{MafDb.ESP6500SI.V2.SSA137-package}
\alias{MafDb.ESP6500SI.V2.SSA137}
\docType{package}

\title{
Annotation package for minor allele frequency data from the NHLBI ESP project
}
\description{
This annotation package stores minor allele frequency (MAF) data values frozen from the NHLBI Exome Sequencing (ESP) project. The data is stored in the form of a SQLite database and is loaded automatically in the form of a MafDb object. The name of the exposed object matches the name of the package and part of the filename that contained the data imported into the package. The class definition and methods to access MafDb objects are found in the \code{\link[VariantFiltering]{VariantFiltering}} software package.
}

\format{
  \tabular{ll}{
    \code{\link{MafDb.ESP6500SI.V2.SSA137}} \tab MafDb object containing MAF values from 6500 ESP exomes downloaded in October 2015 from \url{http://evs.gs.washington.edu/evs_bulk_data/ESP6500SI-V2-SSA137.GRCh38-liftover.snps_indels.vcf.tar.gz}. See \code{\link{makeMafDbPackageESP}} for more information on how to update these data. \cr
  }
}

\author{
R. Castelo
}

\seealso{
  \link{makeMafDbPackageESP}
  \link[MafDb.ALL.wgs.phase1.release.v3.20101123]{MafDb.ALL.wgs.phase1.release.v3.20101123}
  \link[MafDb.ALL.wgs.phase3.release.v5a.20130502]{MafDb.ALL.wgs.phase3.release.v5a.20130502}
  \link[VariantFiltering]{MafDb-class}
  \link[VariantFiltering]{snpid2maf}
  \link[VariantFiltering]{VariantFiltering}
}

\examples{
library(MafDb.ESP6500SI.V2.SSA137)

ls("package:MafDb.ESP6500SI.V2.SSA137")

MafDb.ESP6500SI.V2.SSA137

knownVariantsMAFcols(MafDb.ESP6500SI.V2.SSA137)

## lookup allele frequencies for rs1129038, an SNP associated to blue and brown eye colors
## as reported in Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]
snpid2maf(MafDb.ESP6500SI.V2.SSA137, "rs1129038")
}

\source{
  Exome Variant Server, NHLBI GO Exome Sequencing Project (ESP), Seattle, WA
  (URL: \url{http://evs.gs.washington.edu/EVS}) [October, 2015, accessed]
}

\keyword{package}
\keyword{data}

==> MafDb.ESP6500SI.V2.SSA137_3.3.0.tar.gz: MafDb.ESP6500SI.V2.SSA137/inst/MafDbPkgTemplate/man/MafDb.ESP6500SI.V2.SSA137-package.Rd <==
\name{MafDb.ESP6500SI.V2.SSA137-package}
\alias{MafDb.ESP6500SI.V2.SSA137-package}
\alias{MafDb.ESP6500SI.V2.SSA137}
\docType{package}

\title{
Annotation package for minor allele frequency data from the NHLBI ESP project
}
\description{
This annotation package stores minor allele frequency (MAF) data values frozen from the NHLBI Exome Sequencing (ESP) project. The data is stored in the form of a SQLite database and is loaded automatically in the form of a MafDb object. The name of the exposed object matches the name of the package and part of the filename that contained the data imported into the package. The class definition and methods to access MafDb objects are found in the \code{\link[VariantFiltering]{VariantFiltering}} software package.
}

\format{
  \tabular{ll}{
    \code{\link{MafDb.ESP6500SI.V2.SSA137}} \tab MafDb object containing MAF values from 6500 ESP exomes downloaded in March 2016 from \url{http://evs.gs.washington.edu/evs_bulk_data/ESP6500SI-V2-SSA137.GRCh38-liftover.snps_indels.vcf.tar.gz}. See \code{\link{makeMafDbPackageESP}} for more information on how to update these data. \cr
  }
}

\author{
R. Castelo
}

\seealso{
  \link{makeMafDbPackageESP}
  \link[MafDb.1Kgenomes.phase1.hs37d5]{MafDb.phase1.hs37d5}
  \link[MafDb.1Kgenomes.phase3.hs37d5]{MafDb.phase3.hs37d5}
  \link[VariantFiltering]{MafDb-class}
  \link[VariantFiltering]{snpid2maf}
  \link[VariantFiltering]{VariantFiltering}
}

\examples{
library(MafDb.ESP6500SI.V2.SSA137)

ls("package:MafDb.ESP6500SI.V2.SSA137")

MafDb.ESP6500SI.V2.SSA137

knownVariantsMAFcols(MafDb.ESP6500SI.V2.SSA137)

## lookup allele frequencies for rs1129038, an SNP associated to blue and brown eye colors
## as reported in Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]
snpid2maf(MafDb.ESP6500SI.V2.SSA137, "rs1129038")
}

\source{
  Exome Variant Server, NHLBI GO Exome Sequencing Project (ESP), Seattle, WA
  (URL: \url{http://evs.gs.washington.edu/EVS}) [March, 2016, accessed]
}

\keyword{package}
\keyword{data}
